==> stigmata-1.0.0-src.zip: stigmata-1.0.0/src/main/java/jp/naist/se/stigmata/birthmarks/BirthmarkService.java <==
package jp.naist.se.stigmata.birthmarks;

/*
 * $Id: BirthmarkService.java 130 2007-06-13 10:08:01Z tama3 $
 */

import java.lang.reflect.Constructor;

import jp.naist.se.stigmata.BirthmarkComparator;
import jp.naist.se.stigmata.BirthmarkContext;
import jp.naist.se.stigmata.BirthmarkExtractor;
import jp.naist.se.stigmata.spi.BirthmarkSpi;

/**
 * Service provider interface for birthmarks which are defined in
 * configuration files.
 *
 * @author Haruaki TAMADA
 * @version $Revision: 130 $ $Date: 2007-06-13 19:08:01 +0900 (Wed, 13 Jun 2007) $
 */
public class BirthmarkService extends AbstractBirthmarkService implements BirthmarkSpi{
    private Class<? extends BirthmarkExtractor> extractorClass;
    private Class<? extends BirthmarkComparator> comparatorClass;
    private String type;
    private String displayType;
    private String description;
    private BirthmarkExtractor extractorObject;
    private BirthmarkComparator comparatorObject;
    private boolean userDefined = true;
    private BirthmarkContext context;

    public BirthmarkService(BirthmarkContext context){
        this.context = context;
    }

    public BirthmarkService(){
    }

    public void setBirthmarkContext(BirthmarkContext context){
        this.context = context;
    }

    public void setExtractorClassName(String extractor){
        try{
            Class<?> c;
            if(context == null){
                c = Class.forName(extractor);
            }
            else{
                c = context.getBytecodeContext().findClass(extractor);
            }
            extractorClass = c.asSubclass(BirthmarkExtractor.class);
            extractorObject = null;
        } catch(ClassNotFoundException e){
            e.printStackTrace();
        }
    }

    public void setComparatorClassName(String comparator){
        try{
            Class<?> c;
            if(context == null){
                c = Class.forName(comparator);
            }
            else{
                c = context.getBytecodeContext().findClass(comparator);
            }
            comparatorClass = c.asSubclass(BirthmarkComparator.class);
            comparatorObject = null;
        } catch(ClassNotFoundException e){
            e.printStackTrace();
        }
    }

    public void setType(String type){
        this.type = type;
    }

    /**
     * returns a type of the birthmark this service provides.
     */
    @Override
    public String getType(){
        return type;
    }

    public void setDisplayType(String displayType){
        this.displayType = displayType;
    }

    public String getDisplayType(){
        return displayType;
    }

    public void setDescription(String description){
        this.description = description;
    }

    public String getDescription(){
        String desc = description;
        if(description == null){
            desc = "";
        }
        return desc;
    }

    /**
     * returns a description of the birthmark this service provides.
     */
    @Override
    public String getDefaultDescription(){
        return description;
    }

    public String getExtractorClassName(){
        return extractorClass.getName();
    }

    /**
     * returns a extractor for the birthmark of this service.
     */
    public BirthmarkExtractor getExtractor(){
        if(extractorObject == null){
            try{
                Constructor<? extends BirthmarkExtractor> c = extractorClass.getConstructor(BirthmarkSpi.class);
                extractorObject = c.newInstance(this);
            } catch(Exception e){
                e.printStackTrace();
            }
        }
        return extractorObject;
    }

    public String getComparatorClassName(){
        return comparatorClass.getName();
    }

    /**
     * returns a comparator for the birthmark of this service.
     */
    public BirthmarkComparator getComparator(){
        if(comparatorObject == null){
            try{
                Constructor<? extends BirthmarkComparator> c = comparatorClass.getConstructor(BirthmarkSpi.class);
                comparatorObject = c.newInstance(this);
            } catch(Exception e){
                e.printStackTrace();
            }
        }
        return comparatorObject;
    }

    public boolean isUserDefined(){
        return userDefined;
    }

    public void setUserDefined(boolean userDefined){
        this.userDefined = userDefined;
    }
}

==> stigmata-1.1.0-src.zip: stigmata-1.1.0/src/main/java/jp/naist/se/stigmata/birthmarks/BirthmarkService.java <==
package jp.naist.se.stigmata.birthmarks;

/*
 * $Id: BirthmarkService.java 172 2007-07-16 02:20:34Z tama3 $
 */

import java.lang.reflect.Constructor;

import jp.naist.se.stigmata.BirthmarkComparator;
import jp.naist.se.stigmata.BirthmarkEnvironment;
import jp.naist.se.stigmata.BirthmarkExtractor;
import jp.naist.se.stigmata.spi.BirthmarkSpi;

/**
 * Service provider interface for birthmarks which are defined in
 * configuration files.
 *
 * @author Haruaki TAMADA
 * @version $Revision: 172 $ $Date: 2007-07-16 11:20:34 +0900 (Mon, 16 Jul 2007) $
 */
public class BirthmarkService extends AbstractBirthmarkService implements BirthmarkSpi{
    private Class<? extends BirthmarkExtractor> extractorClass;
    private Class<? extends BirthmarkComparator> comparatorClass;
    private String type;
    private String displayType;
    private String description;
    private BirthmarkExtractor extractorObject;
    private BirthmarkComparator comparatorObject;
    private boolean userDefined = true;
    private BirthmarkEnvironment environment;

    public BirthmarkService(BirthmarkEnvironment environment){
        this.environment = environment;
    }

    public BirthmarkService(){
    }

    public void setBirthmarkEnvironment(BirthmarkEnvironment environment){
        this.environment = environment;
    }

    public void setExtractorClassName(String extractor){
        try{
            Class<?> c;
            if(environment == null){
                c = Class.forName(extractor);
            }
            else{
                c = environment.getClasspathContext().findClass(extractor);
            }
            extractorClass = c.asSubclass(BirthmarkExtractor.class);
            extractorObject = null;
        } catch(ClassNotFoundException e){
            e.printStackTrace();
        }
    }

    public void setComparatorClassName(String comparator){
        try{
            Class<?> c;
            if(environment == null){
                c = Class.forName(comparator);
            }
            else{
                c = environment.getClasspathContext().findClass(comparator);
            }
            comparatorClass = c.asSubclass(BirthmarkComparator.class);
            comparatorObject = null;
        } catch(ClassNotFoundException e){
            e.printStackTrace();
        }
    }

    public void setType(String type){
        this.type = type;
    }

    /**
     * returns a type of the birthmark this service provides.
     */
    @Override
    public String getType(){
        return type;
    }

    public void setDisplayType(String displayType){
        this.displayType = displayType;
    }

    public String getDisplayType(){
        return displayType;
    }

    public void setDescription(String description){
        this.description = description;
    }

    public String getDescription(){
        String desc = description;
        if(description == null){
            desc = "";
        }
        return desc;
    }

    /**
     * returns a description of the birthmark this service provides.
     */
    @Override
    public String getDefaultDescription(){
        return description;
    }

    public String getExtractorClassName(){
        return extractorClass.getName();
    }

    /**
     * returns a extractor for the birthmark of this service.
     */
    public BirthmarkExtractor getExtractor(){
        if(extractorObject == null){
            try{
                Constructor<? extends BirthmarkExtractor> c = extractorClass.getConstructor(BirthmarkSpi.class);
                extractorObject = c.newInstance(this);
            } catch(Exception e){
                e.printStackTrace();
            }
        }
        return extractorObject;
    }

    public String getComparatorClassName(){
        return comparatorClass.getName();
    }

    /**
     * returns a comparator for the birthmark of this service.
     */
    public BirthmarkComparator getComparator(){
        if(comparatorObject == null){
            try{
                Constructor<? extends BirthmarkComparator> c = comparatorClass.getConstructor(BirthmarkSpi.class);
                comparatorObject = c.newInstance(this);
            } catch(Exception e){
                e.printStackTrace();
            }
        }
        return comparatorObject;
    }

    public boolean isUserDefined(){
        return userDefined;
    }

    public void setUserDefined(boolean userDefined){
        this.userDefined = userDefined;
    }
}
